package cn.iocoder.yudao.module.reward.vo.reward;

import com.alibaba.excel.annotation.ExcelProperty;
import com.alibaba.fastjson.JSONArray;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.NotNull;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import static cn.iocoder.yudao.framework.common.util.date.DateUtils.FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND;

/**
* 礼品 Response VO
* @author 系统管理员
*/
@Data
@ApiModel("管理后台 - 礼品 Response VO")
public class RewardBackVO {

    @ExcelProperty("")
    @ApiModelProperty(value = "", required = true)
    private Long id;

    @ExcelProperty("礼品ID")
    @ApiModelProperty(value = "礼品ID", required = true)
    private String code;

    @ExcelProperty("中文名称")
    @ApiModelProperty(value = "中文名称")
    private String titleZh;

    @ExcelProperty("英文名称")
    @ApiModelProperty(value = "英文名称")
    private String titleEn;

    @ExcelProperty("法文名称")
    @ApiModelProperty(value = "法文名称")
    private String titleFr;

    @ExcelProperty("中文礼品图片")
    @ApiModelProperty(value = "中文礼品图片")
    private String imgZh;

    @ExcelProperty("英文礼品图片")
    @ApiModelProperty(value = "英文礼品图片")
    private String imgEn;

    @ExcelProperty("法文礼品图片")
    @ApiModelProperty(value = "法文礼品图片")
    private String imgFr;

    @ExcelProperty("兑换所需积分")
    @ApiModelProperty(value = "兑换所需积分", required = true)
    private Integer pointsRequire;

    @ExcelProperty("兑换网点")
    @ApiModelProperty(value = "兑换网点", required = true)
    private Integer nodeId;

    @ApiModelProperty(value = "兑换网点和积分列表", required = true)
    private List<RewardBackVO.NodeAndPoints> nodeIds = new ArrayList<>();

    @ExcelProperty("已兑换次数")
    @ApiModelProperty(value = "已兑换次数")
    private Integer exchangeCount;

    @ExcelProperty("剩余数量")
    @ApiModelProperty(value = "剩余数量", required = true)
    private Integer quantityRemain;

    @ExcelProperty("活动开始时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "活动开始时间")
    private Date startTime;

    @ExcelProperty("活动结束时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "活动结束时间")
    private Date endTime;

    @ExcelProperty("领取方式（1上门领取，2包邮到家，3邮寄到付）")
    @ApiModelProperty(value = "领取方式（1上门领取，2包邮到家，3邮寄到付）", required = true)
    private String pickMethod;

    @ExcelProperty("领取方式（JSON数组）")
    @ApiModelProperty(value = "领取方式（1上门领取，2包邮到家，3邮寄到付）")
    private JSONArray pickMethodList;

    @ExcelProperty("允许兑换次数")
    @ApiModelProperty(value = "允许兑换次数", required = true)
    private Integer allowCount;

    @ExcelProperty("中文备注")
    @ApiModelProperty(value = "中文备注")
    private String remarkZh;

    @ExcelProperty("英文备注")
    @ApiModelProperty(value = "英文备注")
    private String remarkEn;

    @ExcelProperty("法文备注")
    @ApiModelProperty(value = "法文备注")
    private String remarkFr;

    @ExcelProperty("礼品状态（1已启用，2未启用，3已关闭，4已过期）")
    @ApiModelProperty(value = "礼品状态（1已启用，2未启用，3已关闭，4已过期）", required = true)
    private Integer status;

    @ExcelProperty("创建时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    @ApiModelProperty(value = "创建时间", required = true)
    private Date createTime;

    @Data
    @AllArgsConstructor
    @NoArgsConstructor
    public static class NodeAndPoints {
        @ApiModelProperty(value = "兑换网点")
        private Integer nodeId;
        @ApiModelProperty(value = "兑换网点对应积分")
        private Integer points;
    }
}
