package cn.iocoder.yudao.module.reward.vo.reward;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.ToString;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.util.Date;
import java.util.List;

import static cn.iocoder.yudao.framework.common.util.date.DateUtils.FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND;

@Data
@ToString(callSuper = true)
@ApiModel("管理后台 - 礼品创建 Request VO")
public class RewardCreateReqVO {

    @ApiModelProperty(value = "中文名称")
    @Size(max = 50, message = "名称长度不能超过50")
    private String titleZh;

    @ApiModelProperty(value = "英文名称")
    @Size(max = 50, message = "名称长度不能超过50")
    private String titleEn;

    @ApiModelProperty(value = "法文名称")
    @Size(max = 50, message = "名称长度不能超过50")
    private String titleFr;

    @ApiModelProperty(value = "中文礼品图片")
    private String imgZh;

    @ApiModelProperty(value = "英文礼品图片")
    private String imgEn;

    @ApiModelProperty(value = "法文礼品图片")
    private String imgFr;

    //@ApiModelProperty(value = "兑换所需积分", required = true)
    //@NotNull(message = "兑换所需积分不能为空")
    //@Min(value = 0)
    //private Integer pointsRequire;

    //@ApiModelProperty(value = "兑换网点", required = true)
    //@NotNull(message = "兑换网点不能为空")
    //private Integer nodeId;

    @ApiModelProperty(value = "兑换网点和积分列表", required = true)
    @NotNull(message = "兑换网点列表不能为空")
    private List<NodeAndPoints> nodeIds;

    @ApiModelProperty(value = "剩余数量", required = true)
    @NotNull(message = "剩余数量不能为空")
    @Min(value = 0)
    private Integer quantityRemain;

    @ApiModelProperty(value = "活动开始时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    private Date startTime;

    @ApiModelProperty(value = "活动结束时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    private Date endTime;

    @ApiModelProperty(value = "领取方式（1上门领取，2包邮到家，3邮寄到付）可以多选", required = true)
    @NotNull(message = "领取方式不能为空")
    private String pickMethod;

    @ApiModelProperty(value = "允许兑换次数", required = true)
    @NotNull(message = "允许兑换次数不能为空")
    @Min(value = 0)
    private Integer allowCount;

    @ApiModelProperty(value = "中文备注")
    @Size(max = 500, message = "中文备注长度不能超过500")
    private String remarkZh;

    @ApiModelProperty(value = "英文备注")
    @Size(max = 500, message = "英文备注长度不能超过500")
    private String remarkEn;

    @ApiModelProperty(value = "法文备注")
    @Size(max = 500, message = "法文备注长度不能超过500")
    private String remarkFr;

    @ApiModelProperty(value = "礼品状态（1已启用，2未启用，3已关闭，4已过期）", required = true)
    @NotNull(message = "礼品状态不能为空")
    private Integer status;

    @Data
    public static class NodeAndPoints {
        @ApiModelProperty(value = "兑换网点")
        private Integer nodeId;
        @ApiModelProperty(value = "兑换网点对应积分")
        private Integer points;
    }
}
